@@ -8,23 +8,23 @@ mod tests {
     use super::common::check_browser;
     use webbrowser::Browser;
 
-    #[actix_rt::test]
+    #[tokio::test(flavor = "multi_thread", worker_threads = 2)]
     async fn test_open_default() {
         check_browser(Browser::Default, TEST_PLATFORM).await;
     }
 
-    #[actix_rt::test]
+    #[tokio::test(flavor = "multi_thread", worker_threads = 2)]
     async fn test_open_safari() {
         check_browser(Browser::Safari, TEST_PLATFORM).await;
     }
 
-    #[actix_rt::test]
+    #[tokio::test(flavor = "multi_thread", worker_threads = 2)]
     #[ignore]
     async fn test_open_firefox() {
         check_browser(Browser::Firefox, TEST_PLATFORM).await;
     }
 
-    #[actix_rt::test]
+    #[tokio::test(flavor = "multi_thread", worker_threads = 2)]
     #[ignore]
     async fn test_open_chrome() {
         check_browser(Browser::Chrome, TEST_PLATFORM).await;
