@@ -8,12 +8,12 @@ mod tests {
     use super::common::check_browser;
     use webbrowser::Browser;
 
-    #[actix_rt::test]
+    #[tokio::test(flavor = "multi_thread", worker_threads = 2)]
     async fn test_open_default() {
         check_browser(Browser::Default, TEST_PLATFORM).await;
     }
 
-    #[actix_rt::test]
+    #[tokio::test(flavor = "multi_thread", worker_threads = 2)]
     #[ignore]
     async fn test_open_internet_explorer() {
         check_browser(Browser::InternetExplorer, TEST_PLATFORM).await;
